@@ -13,7 +13,7 @@ our @ISA = qw(DynaLoader);
 # SQL_DRIVER_VER is formatted as dd.dd.dddd
 # for version 5.x please switch to 5.00(_00) version numbering
 # keep $VERSION in Bundle/DBD/mysql.pm in sync
-our $VERSION = '5.009';
+our $VERSION = '5.010';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -738,12 +738,10 @@ EOF
     my @where;
     my @bind;
 
-    # catalogs are not yet supported by MySQL
-
-#    if (defined $catalog) {
-#        push @where, 'TABLE_CATALOG = ?';
-#        push @bind, $catalog;
-#    }
+    if (defined $catalog) {
+        push @where, 'TABLE_CATALOG = ?';
+        push @bind, $catalog;
+    }
 
     if (defined $schema) {
         push @where, 'TABLE_SCHEMA = ?';
@@ -1672,17 +1670,61 @@ header of table names together with all rows:
   }
 
 For portable applications you should restrict yourself to attributes with
-capitalized or mixed case names. Lower case attribute names are private
-to DBD::mysql. The attribute list includes:
+capitalized or mixed case names. Uppercase attribute names are in the 
+statement handle interface described by L<DBI>, while lower case attribute 
+names are private to DBD::mysql. The attribute list includes:
 
 =over
 
+=item NAME
+
+A reference to an array of column names, as per DBI docs.
+
+=item NULLABLE
+
+A reference to an array of boolean values; TRUE indicates that this column
+may contain NULL's.
+
+=item NUM_OF_FIELDS
+
+Number of fields returned by a I<SELECT> or I<LISTFIELDS> statement.
+You may use this for checking whether a statement returned a result:
+A zero value indicates a non-SELECT statement like I<INSERT>,
+I<DELETE> or I<UPDATE>.
+
+=item TYPE
+
+A reference to an array of column types. The engine's native column
+types are mapped to portable types like DBI::SQL_INTEGER() or
+DBI::SQL_VARCHAR(), as good as possible. Not all native types have
+a meaningful equivalent, for example DBD::mysql::FIELD_TYPE_INTERVAL
+is mapped to DBI::SQL_VARCHAR().
+If you need the native column types, use I<mysql_type>. See below.
+
 =item ChopBlanks
 
 this attribute determines whether a I<fetchrow> will chop preceding
 and trailing blanks off the column values. Chopping blanks does not
 have impact on the I<max_length> attribute.
 
+=item ParamValues
+
+This attribute is supported as described in the DBI documentation.
+
+It returns a hashref, the keys of which are the 'names' of the 
+placeholders: integers starting at 1. It returns an empty hashref if 
+the statement has no placeholders.
+
+The values for these keys are initially undef; they are populated with 
+C<bind_param>, or when C<execute> method is called with parameters.  
+(Supplying the parameter values in the arguments to C<execute> will 
+override any previously bound values.)
+
+After execution, it is possible to use C<bind_param> to change a single 
+parameter value and C<execute> the statement again, with other values 
+unchanged. The attribute remains properly populated after the C<finish> 
+method is called, with the values from the last execution.
+
 =item mysql_gtids
 
 Returns GTID(s) if GTID session tracking is ensabled in the server via
@@ -1734,35 +1776,10 @@ the maximum physically present in the result table, I<length> gives
 the theoretically possible maximum. I<max_length> is valid for MySQL
 only.
 
-=item NAME
-
-A reference to an array of column names.
-
-=item NULLABLE
-
-A reference to an array of boolean values; TRUE indicates that this column
-may contain NULL's.
-
-=item NUM_OF_FIELDS
-
-Number of fields returned by a I<SELECT> or I<LISTFIELDS> statement.
-You may use this for checking whether a statement returned a result:
-A zero value indicates a non-SELECT statement like I<INSERT>,
-I<DELETE> or I<UPDATE>.
-
 =item mysql_table
 
 A reference to an array of table names, useful in a I<JOIN> result.
 
-=item TYPE
-
-A reference to an array of column types. The engine's native column
-types are mapped to portable types like DBI::SQL_INTEGER() or
-DBI::SQL_VARCHAR(), as good as possible. Not all native types have
-a meaningful equivalent, for example DBD::mysql::FIELD_TYPE_INTERVAL
-is mapped to DBI::SQL_VARCHAR().
-If you need the native column types, use I<mysql_type>. See below.
-
 =item mysql_type
 
 A reference to an array of MySQL's native column types, for example
